==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebTabHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebTabHeaderElementDescription } from "./WebTabHeaderElementDescription";
/**
 * @hidden
 */
var WebTabHeaderElementDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabHeaderElementDescriptionMetadata, _super);
    function WebTabHeaderElementDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabHeaderElementDescriptionMetadata.b = function (a) {
        if (WebTabHeaderElementDescriptionMetadata.a == null) {
            WebTabHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabHeaderElementDescriptionMetadata.c(WebTabHeaderElementDescriptionMetadata.a);
        }
        if (a.k(WebTabHeaderElementDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebTabHeaderElementDescriptionMetadata.a);
        WebDragServiceDescriptionMetadata.d(a);
    };
    WebTabHeaderElementDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabHeaderElement");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("DragService", "ExportedType:WebDragService");
        WebTabHeaderElementDescriptionMetadata.e(a);
    };
    WebTabHeaderElementDescriptionMetadata.d = function (a) {
        WebTabHeaderElementDescriptionMetadata.b(a);
        a.ad("WebTabHeaderElement", function () { return new WebTabHeaderElementDescription(); });
        a.ac("WebTabHeaderElement", WebTabHeaderElementDescriptionMetadata.a);
    };
    WebTabHeaderElementDescriptionMetadata.e = function (a) {
        a.item("__preferUnsuffixed", "Boolean");
    };
    WebTabHeaderElementDescriptionMetadata.$t = markType(WebTabHeaderElementDescriptionMetadata, 'WebTabHeaderElementDescriptionMetadata');
    WebTabHeaderElementDescriptionMetadata.a = null;
    return WebTabHeaderElementDescriptionMetadata;
}(Base));
export { WebTabHeaderElementDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebTabHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebTabHeaderElementDescription } from "./WebTabHeaderElementDescription";
/**
 * @hidden
 */
var WebTabHeaderElementDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabHeaderElementDescriptionMetadata, _super);
    function WebTabHeaderElementDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabHeaderElementDescriptionMetadata.b = function (a) {
        if (WebTabHeaderElementDescriptionMetadata.a == null) {
            WebTabHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabHeaderElementDescriptionMetadata.c(WebTabHeaderElementDescriptionMetadata.a);
        }
        if (a.k(WebTabHeaderElementDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebTabHeaderElementDescriptionMetadata.a);
        WebDragServiceDescriptionMetadata.d(a);
    };
    WebTabHeaderElementDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabHeaderElement");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("DragService", "ExportedType:WebDragService");
        WebTabHeaderElementDescriptionMetadata.e(a);
    };
    WebTabHeaderElementDescriptionMetadata.d = function (a) {
        WebTabHeaderElementDescriptionMetadata.b(a);
        a.ae("WebTabHeaderElement", function () { return new WebTabHeaderElementDescription(); });
        a.ad("WebTabHeaderElement", WebTabHeaderElementDescriptionMetadata.a);
    };
    WebTabHeaderElementDescriptionMetadata.e = function (a) {
        a.item("__preferUnsuffixed", "Boolean");
    };
    WebTabHeaderElementDescriptionMetadata.$t = markType(WebTabHeaderElementDescriptionMetadata, 'WebTabHeaderElementDescriptionMetadata');
    WebTabHeaderElementDescriptionMetadata.a = null;
    return WebTabHeaderElementDescriptionMetadata;
}(Base));
export { WebTabHeaderElementDescriptionMetadata };
